@@ -1,6 +1,6 @@
 package CSS::DOM::Rule::Media;
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use warnings; no warnings qw 'utf8 parenthesis';
 use strict;
@@ -11,11 +11,12 @@ use CSS::DOM::Exception qw/ SYNTAX_ERR INDEX_SIZE_ERR /;
 
 our @ISA = 'CSS::DOM::Rule';
 
-no constant 1.03 ();
-use constant::lexical { # Don't let this conflict with the superclass.
+use constant 1.03 our $_const = {
+# Don't let this conflict with the superclass.
 	ruls => 2,
 	medi => 3,
 };
+{ no strict; delete @{__PACKAGE__.'::'}{_const => keys %{our $_const}} }
 
 # overrides:
 sub type { CSS::DOM::Rule::MEDIA_RULE }
@@ -111,7 +112,7 @@ CSS::DOM::Rule::Media - CSS @media rule class for CSS::DOM
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =head1 SYNOPSIS
 
